aboutsummaryrefslogtreecommitdiffstats
path: root/src/afm-launch.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/afm-launch.h')
-rw-r--r--src/afm-launch.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/afm-launch.h b/src/afm-launch.h
index ec5a88a..b6c59f6 100644
--- a/src/afm-launch.h
+++ b/src/afm-launch.h
@@ -26,7 +26,7 @@ struct afm_launch_desc {
const char *type; /* type to launch */
const char *name; /* name of the application */
const char *home; /* home directory of the applications */
- const char **plugins; /* plugins for the application */
+ const char **bindings; /* bindings for the application */
int width; /* requested width */
int height; /* requested height */
enum afm_launch_mode mode; /* launch mode */